@@ -6,6 +6,7 @@
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
 import json
 import os
+import sqlite3
 
 from decentra_network.accounts.account import Account
 from decentra_network.config import TEMP_ACCOUNTS_PATH
@@ -17,19 +18,16 @@ def GetAccounts(custom_TEMP_ACCOUNTS_PATH=None):
     Returns the accounts from TEMP_ACCOUNTS_PATH.
     """
 
-    the_TEMP_ACCOUNTS_PATH = (
-        TEMP_ACCOUNTS_PATH
-        if custom_TEMP_ACCOUNTS_PATH is None
-        else custom_TEMP_ACCOUNTS_PATH
-    )
+    the_TEMP_ACCOUNTS_PATH = (TEMP_ACCOUNTS_PATH
+                              if custom_TEMP_ACCOUNTS_PATH is None else
+                              custom_TEMP_ACCOUNTS_PATH)
 
     os.chdir(get_config()["main_folder"])
-    if not os.path.exists(the_TEMP_ACCOUNTS_PATH):
-        return []
-    with open(the_TEMP_ACCOUNTS_PATH, "r") as block_file:
-        the_accounts_json = json.load(block_file)
+    conn = sqlite3.connect(the_TEMP_ACCOUNTS_PATH, check_same_thread=False)
+    c = conn.cursor()
+    c.execute(
+        """CREATE TABLE IF NOT EXISTS account_list (address text, sequance_number integer, balance integer)"""
+    )
+    conn.commit()
 
-    return [
-        Account.load_json(the_accounts_json[account_json])
-        for account_json in the_accounts_json
-    ]
+    return c
