@@ -12,9 +12,9 @@ from flask import Flask
 from flask import jsonify
 from flask import request
 from waitress import serve
+from waitress.server import create_server
 
 sys.path.append(os.path.join(os.path.dirname(__file__), "..", ".."))
-
 from decentra_network.accounts.get_balance import GetBalance
 from decentra_network.blockchain.block.create_block import CreateBlock
 from decentra_network.blockchain.block.get_block import GetBlock
@@ -24,7 +24,8 @@ from decentra_network.lib.export import export_the_transactions
 from decentra_network.lib.log import get_logger
 from decentra_network.lib.perpetualtimer import perpetualTimer
 from decentra_network.lib.safety import safety_check
-from decentra_network.lib.settings_system import (debug_mode, test_mode,
+from decentra_network.lib.settings_system import (d_mode_settings,
+                                                  t_mode_settings,
                                                   the_settings)
 from decentra_network.lib.status import Status
 from decentra_network.node.server.server import server
@@ -44,6 +45,34 @@ logger = get_logger("API")
 
 app = Flask(__name__)
 
+custom_block = None
+custom_current_time = None
+custom_sequence_number = None
+custom_balance = None
+custom_server = None
+
+custom_TEMP_BLOCK_PATH = None
+custom_TEMP_ACCOUNTS_PATH = None
+custom_TEMP_BLOCKSHASH_PATH = None
+custom_TEMP_BLOCKSHASH_PART_PATH = None
+
+account_list = None
+
+custom_wallet = None
+
+custom_CONNECTED_NODES_PATH = None
+
+custom_consensus_trigger = None
+custom_consensus_trigger_result = None
+
+custom_transactions = None
+custom_MY_TRANSACTION_EXPORT_PATH = None
+
+custom_UNL_NODES_PATH = None
+custom_first_block = None
+custom_new_block = None
+custom_connections = None
+
 
 @app.route("/wallet/print", methods=["GET"])
 def print_wallets_page():
@@ -80,13 +109,35 @@ def delete_wallets_page():
 def send_coin_page(address, amount, password):
     logger.info(
         f"{request.remote_addr} {request.method} {request.url} {request.data}")
-    block = GetBlock()
-    send_tx = send(block, password, address, amount)
+    block = (GetBlock(custom_TEMP_BLOCK_PATH=custom_TEMP_BLOCK_PATH)
+             if custom_block is None else custom_block)
+    send_tx = send(
+        block,
+        password,
+        address,
+        amount,
+        custom_current_time=custom_current_time,
+        custom_sequence_number=custom_sequence_number,
+        custom_balance=custom_balance,
+    )
     if send_tx != False:
         SavetoMyTransaction(send_tx)
-        server.send_transaction(send_tx)
-        SaveBlock(block)
-    return jsonify("OK")
+        server.send_transaction(
+            send_tx,
+            custom_current_time=custom_current_time,
+            custom_sequence_number=custom_sequence_number,
+            custom_balance=custom_balance,
+            custom_server=custom_server,
+        )
+        SaveBlock(
+            block,
+            custom_TEMP_BLOCK_PATH=custom_TEMP_BLOCK_PATH,
+            custom_TEMP_ACCOUNTS_PATH=custom_TEMP_ACCOUNTS_PATH,
+            custom_TEMP_BLOCKSHASH_PATH=custom_TEMP_BLOCKSHASH_PATH,
+            custom_TEMP_BLOCKSHASH_PART_PATH=custom_TEMP_BLOCKSHASH_PART_PATH,
+        )
+    result = send_tx.dump_json() if send_tx != False else False
+    return jsonify(result)
 
 
 @app.route("/send/coin-data/<address>/<amount>/<data>/<password>",
@@ -94,20 +145,48 @@ def send_coin_page(address, amount, password):
 def send_coin_data_page(address, amount, data, password):
     logger.info(
         f"{request.remote_addr} {request.method} {request.url} {request.data}")
-    block = GetBlock()
-    send_tx = send(block, password, address, amount, data)
+    block = (GetBlock(custom_TEMP_BLOCK_PATH=custom_TEMP_BLOCK_PATH)
+             if custom_block is None else custom_block)
+    send_tx = send(
+        block,
+        password,
+        address,
+        amount,
+        data=data,
+        custom_current_time=custom_current_time,
+        custom_sequence_number=custom_sequence_number,
+        custom_balance=custom_balance,
+    )
     if send_tx != False:
         SavetoMyTransaction(send_tx)
-        server.send_transaction(send_tx)
-        SaveBlock(block)
-    return jsonify("OK")
+        server.send_transaction(
+            send_tx,
+            custom_current_time=custom_current_time,
+            custom_sequence_number=custom_sequence_number,
+            custom_balance=custom_balance,
+            custom_server=custom_server,
+        )
+        SaveBlock(
+            block,
+            custom_TEMP_BLOCK_PATH=custom_TEMP_BLOCK_PATH,
+            custom_TEMP_ACCOUNTS_PATH=custom_TEMP_ACCOUNTS_PATH,
+            custom_TEMP_BLOCKSHASH_PATH=custom_TEMP_BLOCKSHASH_PATH,
+            custom_TEMP_BLOCKSHASH_PART_PATH=custom_TEMP_BLOCKSHASH_PART_PATH,
+        )
+    result = send_tx.dump_json() if send_tx != False else False
+    return jsonify(result)
 
 
 @app.route("/wallet/balance", methods=["GET"])
 def balance_wallets_page():
     logger.info(
         f"{request.remote_addr} {request.method} {request.url} {request.data}")
-    return jsonify(GetBalance(GetBlock(), wallet_import(-1, 0)))
+    the_wallet = wallet_import(-1,
+                               0) if custom_wallet is None else custom_wallet
+    the_block = (GetBlock(custom_TEMP_BLOCK_PATH=custom_TEMP_BLOCK_PATH)
+                 if custom_block is None else custom_block)
+    return jsonify(GetBalance(the_block, the_wallet,
+                              account_list=account_list))
 
 
 @app.route("/node/start/<ip>/<port>", methods=["GET"])
@@ -138,7 +217,10 @@ def node_connect_page(ip, port):
 def node_connectmixdb_page():
     logger.info(
         f"{request.remote_addr} {request.method} {request.url} {request.data}")
-    server.connectionfrommixdb()
+    server.connectionfrommixdb(
+        custom_server=custom_server,
+        custom_CONNECTED_NODES_PATH=custom_CONNECTED_NODES_PATH,
+    )
     return jsonify("OK")
 
 
@@ -162,7 +244,7 @@ def node_id_page():
 def settings_test_on_page():
     logger.info(
         f"{request.remote_addr} {request.method} {request.url} {request.data}")
-    test_mode(True)
+    t_mode_settings(True)
     return jsonify("OK")
 
 
@@ -170,7 +252,7 @@ def settings_test_on_page():
 def settings_test_off_page():
     logger.info(
         f"{request.remote_addr} {request.method} {request.url} {request.data}")
-    test_mode(False)
+    t_mode_settings(False)
     return jsonify("OK")
 
 
@@ -179,7 +261,7 @@ def settings_debug_on_page():
     logger.info(
         f"{request.remote_addr} {request.method} {request.url} {request.data}")
     app.config["DEBUG"] = True
-    debug_mode(True)
+    d_mode_settings(True)
     return jsonify("OK")
 
 
@@ -188,7 +270,7 @@ def settings_debug_off_page():
     logger.info(
         f"{request.remote_addr} {request.method} {request.url} {request.data}")
     app.config["DEBUG"] = False
-    debug_mode(False)
+    d_mode_settings(False)
     return jsonify("OK")
 
 
@@ -196,14 +278,27 @@ def settings_debug_off_page():
 def block_get_page():
     logger.info(
         f"{request.remote_addr} {request.method} {request.url} {request.data}")
+    the_server = server.Server if custom_server is None else custom_server
     if the_settings()["test_mode"]:
-        the_block = CreateBlock()
-        SaveBlock(the_block)
-        server.Server.send_block_to_other_nodes()
+        the_block = CreateBlock(custom_TEMP_BLOCK_PATH=custom_TEMP_BLOCK_PATH)
+        SaveBlock(
+            the_block,
+            custom_TEMP_BLOCK_PATH=custom_TEMP_BLOCK_PATH,
+            custom_TEMP_ACCOUNTS_PATH=custom_TEMP_ACCOUNTS_PATH,
+            custom_TEMP_BLOCKSHASH_PATH=custom_TEMP_BLOCKSHASH_PATH,
+            custom_TEMP_BLOCKSHASH_PART_PATH=custom_TEMP_BLOCKSHASH_PART_PATH,
+        )
+        the_server.send_block_to_other_nodes()
         logger.info("Consensus timer is started")
-        perpetualTimer(the_block.consensus_timer, consensus_trigger)
+        the_consensus_trigger = (consensus_trigger
+                                 if custom_consensus_trigger is None else
+                                 custom_consensus_trigger)
+        trigger = perpetualTimer(the_block.consensus_timer,
+                                 the_consensus_trigger)
+        global custom_consensus_trigger_result
+        custom_consensus_trigger_result = trigger
     else:
-        server.Server.send_me_full_block()
+        the_server.send_me_full_block()
     return jsonify("OK")
 
 
@@ -211,10 +306,11 @@ def block_get_page():
 def export_transaction_csv_page():
     logger.info(
         f"{request.remote_addr} {request.method} {request.url} {request.data}")
-    if export_the_transactions():
-        return jsonify("OK")
-    else:
-        return jsonify("You have not a transaction")
+    return jsonify(
+        export_the_transactions(
+            custom_transactions=custom_transactions,
+            custom_MY_TRANSACTION_EXPORT_PATH=custom_MY_TRANSACTION_EXPORT_PATH,
+        ))
 
 
 @app.route("/export/transactions/json", methods=["GET"])
@@ -229,10 +325,18 @@ def export_transaction_json_page():
 def status_page():
     logger.info(
         f"{request.remote_addr} {request.method} {request.url} {request.data}")
-    return jsonify(Status())
+    return jsonify(
+        Status(
+            custom_TEMP_BLOCK_PATH=custom_TEMP_BLOCK_PATH,
+            custom_UNL_NODES_PATH=custom_UNL_NODES_PATH,
+            custom_first_block=custom_first_block,
+            custom_new_block=custom_new_block,
+            custom_connections=custom_connections,
+            custom_transactions=custom_transactions,
+        ))
 
 
-def start():
+def start(port=None, test=False):
     """
     Start the API server.
     """
@@ -264,10 +368,14 @@ def start():
 
     args = parser.parse_args()
 
+    args.port = args.port if port is None else int(port)
+
     safety_check(args.interface, args.timeout)
 
     logger.info(f"Starting API on port {args.port}")
-    serve(app, host="0.0.0.0", port=args.port)
+    result = (serve(app, host="0.0.0.0", port=args.port) if test is False else
+              create_server(app, host="0.0.0.0", port=args.port))
+    return result
 
 
 if __name__ == "__main__":
