@@ -12,14 +12,14 @@ CONNECTED_NODES_PATH = "db/connected_nodes/"
 UNL_NODES_PATH = "db/unl_nodes.json"
 
 TEMP_BLOCK_PATH = "db/temp_block.decentra_network.json"
-TEMP_ACCOUNTS_PATH = "db/temp_accounts.decentra_network.json"
+TEMP_ACCOUNTS_PATH = "db/temp_accounts.decentra_network.db"
 TEMP_BLOCKSHASH_PATH = "db/temp_blockshash.decentra_network.json"
 TEMP_BLOCKSHASH_PART_PATH = "db/temp_blockshash_part.decentra_network.json"
 
 TEMP_CANDIDATE_BLOCKS_PATH = "db/temp_candidate_blocks.decentra_network.json"
 
 LOADING_BLOCK_PATH = "db/loading_block.decentra_network.json"
-LOADING_ACCOUNTS_PATH = "db/loading_block_accounts.decentra_network.json"
+LOADING_ACCOUNTS_PATH = "db/loading_block_accounts.decentra_network.db"
 LOADING_BLOCKSHASH_PATH = "db/loading_block_blockshash.decentra_network.json"
 LOADING_BLOCKSHASH_PART_PATH = "db/loading_block_blockshash_part.decentra_network.json"
 
