@@ -67,6 +67,7 @@ class server(Thread):
         custom_LOADING_BLOCKSHASH_PART_PATH=None,
         custom_CONNECTED_NODES_PATH=None,
         custom_PENDING_TRANSACTIONS_PATH=None,
+        time_control=None,
     ):
         Thread.__init__(self)
         self.running = True
@@ -81,6 +82,7 @@ class server(Thread):
         self.clients = []
 
         self.messages = []
+        self.our_messages = []
         self.save_messages = save_messages
 
         self.TEMP_BLOCK_PATH = (TEMP_BLOCK_PATH
@@ -121,6 +123,8 @@ class server(Thread):
 
         self.custom_variables = custom_variables
 
+        self.time_control = 10 if time_control is None else time_control
+
         if not test:
             self.__class__.Server = self
             self.start()
@@ -159,6 +163,7 @@ class server(Thread):
 
     def prepare_message(self, data):
         data["id"] = server.id
+        data["timestamp"] = str(time.time())
         sign = Ecdsa.sign(
             str(data),
             PrivateKey.fromPem(wallet_import(0, 1)),
@@ -176,12 +181,25 @@ class server(Thread):
         for a_client in self.clients:
             if a_client != except_client:
                 self.send_client(a_client, data, ready_to_send=True)
+        try:
+            del data["buffer"]
+        except KeyError:
+            pass
         return data
 
     def send_client(self, node, data, ready_to_send=False):
         if not ready_to_send:
             data = self.prepare_message(data)
+        if len(json.dumps(data).encode("utf-8")) < 6525:
+            data["buffer"] = "0" * (
+                (6525 - len(json.dumps(data).encode("utf-8"))) - 14)
+        print(len(json.dumps(data).encode("utf-8")))
         node.socket.sendall(json.dumps(data).encode("utf-8"))
+        with contextlib.suppress(KeyError):
+            del data["buffer"]
+        time.sleep(0.02)
+        if self.save_messages:
+            self.our_messages.append(data)
         return data
 
     def get_message(self, client, data):
@@ -199,6 +217,11 @@ class server(Thread):
             return False
         if "signature" not in data:
             return False
+        if "timestamp" not in data:
+            return False
+        the_control = time.time() - float(data["timestamp"])
+        if the_control > self.time_control:
+            return False
         # remove sign from data
         sign = data["signature"]
         del data["signature"]
@@ -281,8 +304,11 @@ class server(Thread):
         node_list = the_server.get_connected_nodes(
             custom_CONNECTED_NODES_PATH=the_CONNECTED_NODES_PATH)
         for element in node_list:
-            the_server.connect(node_list[element]["host"],
-                               node_list[element]["port"])
+            with contextlib.suppress(Exception):
+                the_server.connect(
+                    node_list[element]["host"],
+                    node_list[element]["port"],
+                )
 
     def connected_node_delete(self, node):
         """
@@ -340,7 +366,6 @@ class server(Thread):
         data = {
             "action": "myblock",
             "transaction": new_list,
-            "sequance_number": system.sequance_number,
         }
         self.send(data)
 
@@ -350,14 +375,11 @@ class server(Thread):
         data = {
             "action": "myblockhash",
             "hash": system.hash,
-            "sequance_number": system.sequance_number,
         }
 
         self.send(data)
 
     def get_candidate_block(self, data, node):
-        logger.info("Getting candidate block: {}".format(
-            data["sequance_number"]))
 
         node.candidate_block = data
 
@@ -395,6 +417,7 @@ class server(Thread):
                     self.send_client(node, data)
 
     def send_full_accounts(self, node=None):
+
         the_TEMP_ACCOUNTS_PATH = self.TEMP_ACCOUNTS_PATH
         file = open(the_TEMP_ACCOUNTS_PATH, "rb")
         SendData = file.read(1024)
@@ -404,13 +427,13 @@ class server(Thread):
                 "action": "fullaccounts",
                 "byte": (SendData.decode(encoding="iso-8859-1")),
             }
+
             if node is None:
                 self.send(data)
             else:
                 self.send_client(node, data)
 
             SendData = file.read(1024)
-
             if not SendData:
                 data = {"action": "fullaccounts", "byte": "end"}
                 if node is None:
